@@ -68,7 +68,7 @@ def get_script_name_key(job_type):
 
 def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_type=clusters.CLUSTER_TYPE_PERSISTENT,
                          git_ref='master', parameters=None, notify_on_job_finish=True, is_control_script=False,
-                         pig_version=None, use_spot_instances=False, pipeline_job_id=None, job_type=JOB_TYPE_PIG,
+                         pig_version=None, use_spot_instances=True, pipeline_job_id=None, job_type=JOB_TYPE_PIG,
                          cluster_tags=[], instance_type=None, project_build=None, cluster_configuration=None):
     """
     Post a new job to a new cluster.
@@ -104,7 +104,7 @@ def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_t
     :param pig_version: Major version of pig to run.  If null, uses the Mortar platform default (currently 0.9).
 
     :type use_spot_instances: bool
-    :param use_spot_instances: whether to launch a cluster using spot instances. Default: false.
+    :param use_spot_instances: whether to launch a cluster using spot instances. Default: true.
 
     :type pipeline_job_id: string
     :param pipeline_job_id: Luigi pipeline that launched this job, if applicable. Default: None.
@@ -149,7 +149,7 @@ def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_t
 
 
 def post_web_job_new_cluster(api, script_name, cluster_size, cluster_type=clusters.CLUSTER_TYPE_PERSISTENT,
-                             parameters=None, notify_on_job_finish=True, pig_version=None, use_spot_instances=False,
+                             parameters=None, notify_on_job_finish=True, pig_version=None, use_spot_instances=True,
                              job_type=JOB_TYPE_PIG, cluster_configuration=None):
     """
     Post a new job to a new cluster.
@@ -176,7 +176,7 @@ def post_web_job_new_cluster(api, script_name, cluster_size, cluster_type=cluste
     :param pig_version: Major version of pig to run.  If null, uses the Mortar platform default (currently 0.9).
 
     :type use_spot_instances: bool
-    :param use_spot_instances: whether to launch a cluster using spot instances. Default: false.
+    :param use_spot_instances: whether to launch a cluster using spot instances. Default: true.
 
     :type job_type: string
     :param job_type: Type of the job. Default: pig.
